/* eslint-disable no-magic-numbers */
import { useEffect } from 'react';
import { MapConfig, MapInstance } from '../../MapViewer.types';
import { useOlMapPinsLayer } from './pinsLayer/useOlMapPinsLayer';
import { useOlMapReactionsLayer } from './reactionsLayer/useOlMapReactionsLayer';
import { useOlMapTileLayer } from './useOlMapTileLayer';

interface UseOlMapLayersInput {
  mapInstance: MapInstance;
}

export const useOlMapLayers = ({ mapInstance }: UseOlMapLayersInput): MapConfig['layers'] => {
  const tileLayer = useOlMapTileLayer();
  const pinsLayer = useOlMapPinsLayer();
  const reactionsLayer = useOlMapReactionsLayer();

  useEffect(() => {
    if (!mapInstance) {
      return;
    }

    mapInstance.setLayers([tileLayer, reactionsLayer, pinsLayer]);
  }, [reactionsLayer, tileLayer, pinsLayer, mapInstance]);

  return [tileLayer, pinsLayer, reactionsLayer];
};
