/* eslint-disable no-magic-numbers */
import { FIRST_ARRAY_ELEMENT, SIZE_OF_EMPTY_ARRAY } from '@/constants/common';
import { bioEntityResponseFixture } from '@/models/fixtures/bioEntityContentsFixture';
import { reactionsFixture } from '@/models/fixtures/reactionFixture';
import {
  ELEMENT_SEARCH_RESULT_MOCK_ALIAS,
  ELEMENT_SEARCH_RESULT_MOCK_REACTION,
} from '@/models/mocks/elementSearchResultMock';
import { apiPath } from '@/redux/apiPath';
import { mockNetworkNewAPIResponse, mockNetworkResponse } from '@/utils/mockNetworkResponse';
import { getReduxStoreWithActionsListener } from '@/utils/testing/getReduxStoreActionsListener';
import { HttpStatusCode } from 'axios';
import { handleReactionResults } from './handleReactionResults';

const mockedAxiosOldClient = mockNetworkResponse();
const mockedAxiosNewClient = mockNetworkNewAPIResponse();

describe('handleReactionResults - util', () => {
  const { store } = getReduxStoreWithActionsListener();
  const { dispatch } = store;

  mockedAxiosNewClient
    .onGet(
      apiPath.getBioEntityContentsStringWithQuery({
        searchQuery: ELEMENT_SEARCH_RESULT_MOCK_ALIAS.id.toString(),
        isPerfectMatch: true,
      }),
    )
    .reply(HttpStatusCode.Ok, bioEntityResponseFixture);

  mockedAxiosOldClient
    .onGet(apiPath.getReactionsWithIds([ELEMENT_SEARCH_RESULT_MOCK_REACTION.id]))
    .reply(HttpStatusCode.Ok, reactionsFixture);

  beforeAll(async () => {
    handleReactionResults(dispatch)(ELEMENT_SEARCH_RESULT_MOCK_REACTION);
  });

  it('should run getReactionsByIds as first action', () => {
    const actions = store.getActions();
    expect(actions.length).toBeGreaterThan(SIZE_OF_EMPTY_ARRAY);
    expect(actions[0].type).toEqual('reactions/getByIds/pending');
    expect(actions[1].type).toEqual('reactions/getByIds/fulfilled');
  });

  it('should run openReactionDrawerById to empty array as second action', () => {
    const actions = store.getActions();
    expect(actions.length).toBeGreaterThan(SIZE_OF_EMPTY_ARRAY);
    expect(actions[2].type).toEqual('drawer/openReactionDrawerById');
    expect(actions[2].payload).toEqual(reactionsFixture[FIRST_ARRAY_ELEMENT].id);
  });

  it('should run setBioEntityContent to empty array as third action', () => {
    const actions = store.getActions();
    expect(actions.length).toBeGreaterThan(SIZE_OF_EMPTY_ARRAY);
    expect(actions[3].type).toEqual('project/getMultiBioEntity/pending');
  });

  it('should run getBioEntity as fourth action', () => {
    const actions = store.getActions();
    expect(actions.length).toBeGreaterThan(SIZE_OF_EMPTY_ARRAY);
    expect(actions[4].type).toEqual('project/getBioEntityContents/pending');
  });
});
