import { STEP } from '@/constants/searchDrawer';
import type {
  DrawerState,
  OpenBioEntityDrawerByIdAction,
  OpenReactionDrawerByIdAction,
  OpenSearchDrawerWithSelectedTabReducerAction,
} from '@/redux/drawer/drawer.types';
import type { DrawerName } from '@/types/drawerName';
import type { PayloadAction } from '@reduxjs/toolkit';

export const openDrawerReducer = (state: DrawerState, action: PayloadAction<DrawerName>): void => {
  state.isOpen = true;
  state.drawerName = action.payload;
};

export const openSearchDrawerWithSelectedTabReducer = (
  state: DrawerState,
  action: OpenSearchDrawerWithSelectedTabReducerAction,
): void => {
  state.isOpen = true;
  state.drawerName = 'search';
  state.searchDrawerState.currentStep = STEP.FIRST;
  state.searchDrawerState.selectedSearchElement = action.payload;
};

export const openSubmapsDrawerReducer = (state: DrawerState): void => {
  state.isOpen = true;
  state.drawerName = 'submaps';
};

export const selectTabReducer = (
  state: DrawerState,
  action: OpenSearchDrawerWithSelectedTabReducerAction,
): void => {
  state.searchDrawerState.currentStep = STEP.FIRST;
  state.searchDrawerState.selectedSearchElement = action.payload;
};

export const closeDrawerReducer = (state: DrawerState): void => {
  state.isOpen = false;
  state.drawerName = 'none';
  state.searchDrawerState.currentStep = STEP.FIRST;
  state.searchDrawerState.selectedValue = undefined;
  state.searchDrawerState.stepType = 'none';
};

export const displayDrugsListReducer = (state: DrawerState): void => {
  state.drawerName = 'search';
  state.searchDrawerState.currentStep = STEP.SECOND;
  state.searchDrawerState.stepType = 'drugs';
};

export const displayChemicalsListReducer = (state: DrawerState): void => {
  state.drawerName = 'search';
  state.searchDrawerState.currentStep = STEP.SECOND;
  state.searchDrawerState.stepType = 'chemicals';
};

export const displayBioEntitiesListReducer = (
  state: DrawerState,
  action: PayloadAction<DrawerState['searchDrawerState']['listOfBioEnitites']>,
): void => {
  state.drawerName = 'search';
  state.searchDrawerState.currentStep = STEP.SECOND;
  state.searchDrawerState.listOfBioEnitites = action.payload;
  state.searchDrawerState.stepType = 'bioEntity';
};

export const displayGroupedSearchResultsReducer = (state: DrawerState): void => {
  state.searchDrawerState.currentStep = STEP.FIRST;
  state.searchDrawerState.stepType = 'none';
};

export const displayEntityDetailsReducer = (
  state: DrawerState,
  action: PayloadAction<DrawerState['searchDrawerState']['selectedValue']>,
): void => {
  state.searchDrawerState.currentStep = STEP.THIRD;
  state.searchDrawerState.selectedValue = action.payload;
};

export const openReactionDrawerByIdReducer = (
  state: DrawerState,
  action: OpenReactionDrawerByIdAction,
): void => {
  state.isOpen = true;
  state.drawerName = 'reaction';
  state.reactionDrawerState.reactionId = action.payload;
};

export const openBioEntityDrawerByIdReducer = (
  state: DrawerState,
  action: OpenBioEntityDrawerByIdAction,
): void => {
  state.isOpen = true;
  state.drawerName = 'bio-entity';
  state.bioEntityDrawerState.bioentityId = action.payload;
  state.searchDrawerState.selectedSearchElement = action.payload.toString();
};
