import { ZERO } from '@/constants/common';
import { ActionReducerMapBuilder } from '@reduxjs/toolkit';
import { getPointMerged } from '../../utils/object/getPointMerged';
import { MAIN_MAP } from './map.constants';
import {
  initMapBackground,
  initMapPosition,
  initMapSizeAndModelId,
  initOpenedMaps,
} from './map.thunks';
import {
  CloseMapAction,
  MapState,
  OpenMapAndSetActiveAction,
  SetActiveMapAction,
  SetBackgroundAction,
  SetMapDataAction,
  SetMapPositionDataAction,
} from './map.types';

export const setMapDataReducer = (state: MapState, action: SetMapDataAction): void => {
  const payload = action.payload || {};

  state.data = {
    ...state.data,
    ...payload,
  };
};

export const setMapPositionReducer = (state: MapState, action: SetMapPositionDataAction): void => {
  const position = action.payload || {};
  const statePosition = state.data.position;

  state.data = {
    ...state.data,
    position: {
      initial: getPointMerged(position || {}, statePosition.initial),
      last: getPointMerged(position || {}, statePosition.last),
    },
  };
};

const updateLastPositionOfCurrentlyActiveMap = (state: MapState): void => {
  const currentMapId = state.data.modelId;
  const currentOpenedMap = state.openedMaps.find(openedMap => openedMap.modelId === currentMapId);
  if (currentOpenedMap) {
    currentOpenedMap.lastPosition = state.data.position.last;
  }
};

export const setActiveMapReducer = (state: MapState, action: SetActiveMapAction): void => {
  updateLastPositionOfCurrentlyActiveMap(state);
  state.data.modelId = action.payload.modelId;
};

export const openMapAndSetActiveReducer = (
  state: MapState,
  action: OpenMapAndSetActiveAction,
): void => {
  updateLastPositionOfCurrentlyActiveMap(state);

  state.openedMaps.push({
    modelId: action.payload.modelId,
    modelName: action.payload.modelName,
    lastPosition: { x: 0, y: 0, z: 0 },
  });
  state.data.modelId = action.payload.modelId;
};

export const closeMapReducer = (state: MapState, action: CloseMapAction): void => {
  state.openedMaps = state.openedMaps.filter(
    openedMap => openedMap.modelId !== action.payload.modelId,
  );
};

export const closeMapAndSetMainMapActiveReducer = (
  state: MapState,
  action: CloseMapAction,
): void => {
  state.openedMaps = state.openedMaps.filter(
    openedMap => openedMap.modelId !== action.payload.modelId,
  );
  state.data.modelId =
    state.openedMaps.find(openedMap => openedMap.modelName === MAIN_MAP)?.modelId || ZERO;
};

export const setMapBackgroundReducer = (state: MapState, action: SetBackgroundAction): void => {
  state.data.backgroundId = action.payload;
};

export const initMapSizeAndModelIdReducer = (builder: ActionReducerMapBuilder<MapState>): void => {
  builder.addCase(initMapSizeAndModelId.fulfilled, (state, action) => {
    state.data.modelId = action.payload.modelId;
    state.data.size = action.payload.size;
  });
};

export const initMapPositionReducers = (builder: ActionReducerMapBuilder<MapState>): void => {
  builder.addCase(initMapPosition.fulfilled, (state, action) => {
    state.data.position = action.payload;
  });
};

export const initMapBackgroundsReducer = (builder: ActionReducerMapBuilder<MapState>): void => {
  builder.addCase(initMapBackground.fulfilled, (state, action) => {
    state.data.backgroundId = action.payload;
    state.loading = 'succeeded';
  });
};

export const initOpenedMapsReducer = (builder: ActionReducerMapBuilder<MapState>): void => {
  builder.addCase(initOpenedMaps.fulfilled, (state, action) => {
    state.openedMaps = action.payload;
  });
};
