import { createSlice } from '@reduxjs/toolkit';
import { MAP_DATA_INITIAL_STATE, OPENED_MAPS_INITIAL_STATE } from './map.constants';
import {
  closeMapAndSetMainMapActiveReducer,
  closeMapReducer,
  openMapAndSetActiveReducer,
  setActiveMapReducer,
  setMapDataReducer,
  initMapPositionReducers,
  setMapPositionReducer,
  initOpenedMapsReducer,
  initMapSizeAndModelIdReducer,
  initMapBackgroundsReducer,
  setMapBackgroundReducer,
} from './map.reducers';
import { MapState } from './map.types';

const initialState: MapState = {
  data: MAP_DATA_INITIAL_STATE,
  loading: 'idle',
  error: { name: '', message: '' },
  openedMaps: OPENED_MAPS_INITIAL_STATE,
};

const mapSlice = createSlice({
  name: 'map',
  initialState,
  reducers: {
    setMapData: setMapDataReducer,
    setActiveMap: setActiveMapReducer,
    openMapAndSetActive: openMapAndSetActiveReducer,
    closeMap: closeMapReducer,
    closeMapAndSetMainMapActive: closeMapAndSetMainMapActiveReducer,
    setMapPosition: setMapPositionReducer,
    setMapBackground: setMapBackgroundReducer,
  },
  extraReducers: builder => {
    initMapPositionReducers(builder);
    initMapSizeAndModelIdReducer(builder);
    initMapBackgroundsReducer(builder);
    initOpenedMapsReducer(builder);
  },
});

export const {
  setMapData,
  setActiveMap,
  openMapAndSetActive,
  closeMap,
  closeMapAndSetMainMapActive,
  setMapPosition,
  setMapBackground,
} = mapSlice.actions;

export default mapSlice.reducer;
