import { elementSearchResult } from '@/models/elementSearchResult';
import { apiPath } from '@/redux/apiPath';
import { axiosInstance } from '@/services/api/utils/axiosInstance';
import { Point } from '@/types/map';
import { ElementSearchResult } from '@/types/models';
import { z } from 'zod';
import { validateDataUsingZodSchema } from '../validateDataUsingZodSchema';

interface Args {
  point: Point;
  currentModelId: number;
}

export const getElementsByPoint = async ({
  point,
  currentModelId,
}: Args): Promise<ElementSearchResult[] | undefined> => {
  const response = await axiosInstance.get<ElementSearchResult[]>(
    apiPath.getSingleBioEntityContentsStringWithCoordinates(point, currentModelId),
  );

  const isDataValid = validateDataUsingZodSchema(response.data, z.array(elementSearchResult));

  return isDataValid ? response.data : undefined;
};
